==> lms-0.0.x-dev.tar.gz: lms/opigno_learning_path/src/Plugin/views/filter/OpignoGroupMembershipBoolean.php <==
<?php

namespace Drupal\opigno_learning_path\Plugin\views\filter;

use Drupal\Core\Form\FormStateInterface;
use Drupal\group\Entity\GroupContent;
use Drupal\views\Plugin\views\filter\BooleanOperator;

/**
 * Filter handler to show trainings filter.
 *
 * @ingroup views_field_handlers
 *
 * @ViewsFilter("opigno_group_membership_boolean")
 */
class OpignoGroupMembershipBoolean extends BooleanOperator {

  public $no_operator = TRUE;

  /**
   * {@inheritdoc}
   */
  protected function operators() {
    // We don't need any operators.
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function getValueOptions() {
    // Specify available options.
    $this->valueOptions = [
      0 => $this->t('All trainings'),
      1 => $this->t('My trainings'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function valueForm(&$form, FormStateInterface $form_state) {
    if (empty($this->valueOptions)) {
      // Initialize the array of possible values for this filter.
      $this->getValueOptions();
    }
    $exposed = $form_state->get('exposed');
    $form['value'] = [
      '#type' => 'radios',
      '#title' => $this->value_value,
      '#options' => $this->valueOptions,
      '#default_value' => $this->value,
    ];
    if (!empty($this->options['exposed'])) {
      $identifier = $this->options['expose']['identifier'];
      $user_input = $form_state->getUserInput();
      if ($exposed && !isset($user_input[$identifier])) {
        $user_input[$identifier] = $this->value;
        $form_state->setUserInput($user_input);
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public function query() {
    $value = $this->value;
    if ($value) {
      $alias = $this->ensureMyTable();
      // Get current user and take filter value.
      $user = \Drupal::currentUser();

      $membership_loader = \Drupal::service('group.membership_loader');
      $memberships = $membership_loader->loadByUser($user);
      $gids = [];
      foreach ($memberships as $membership) {
        $group = $membership->getGroup();
        $gids[] = $group->id();
        if ($group->bundle() === 'opigno_class') {
          $parent_group_content = GroupContent::loadByEntity($group);
          foreach ($parent_group_content as $group_content) {
            $gids[] = $group_content->getGroup()->id();
          }
        }
      }
      $field = $alias . '.id';
      $gids = array_unique($gids);
      if ($gids) {
        // Add condition to select only items with membership.
        $this->query->addWhere($this->options['group'], $field, $gids, 'IN');
      }
      else {
        $this->query->addWhere($this->options['group'], $field, -1, '=');
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  protected function exposedTranslate(&$form, $type) {
    parent::exposedTranslate($form, $type);
    if ($form['#type'] == 'select') {
      $form['#type'] = 'radios';
    }
  }

}

==> lms-0.2.x-dev.tar.gz: lms/opigno_learning_path/src/Plugin/views/filter/OpignoGroupMembershipBoolean.php <==
<?php

namespace Drupal\opigno_learning_path\Plugin\views\filter;

use Drupal\Core\Form\FormStateInterface;
use Drupal\group\Entity\GroupRelationship;
use Drupal\views\Plugin\views\filter\BooleanOperator;

/**
 * Filter handler to show trainings filter.
 *
 * @ingroup views_field_handlers
 *
 * @ViewsFilter("opigno_group_membership_boolean")
 */
class OpignoGroupMembershipBoolean extends BooleanOperator {

  public $no_operator = TRUE;

  /**
   * {@inheritdoc}
   */
  public function operators() {
    // We don't need any operators.
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function getValueOptions() {
    // Specify available options.
    $this->valueOptions = [
      0 => $this->t('All trainings'),
      1 => $this->t('My trainings'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function valueForm(&$form, FormStateInterface $form_state) {
    if (empty($this->valueOptions)) {
      // Initialize the array of possible values for this filter.
      $this->getValueOptions();
    }
    $exposed = $form_state->get('exposed');
    $form['value'] = [
      '#type' => 'radios',
      '#title' => $this->value_value,
      '#options' => $this->valueOptions,
      '#default_value' => $this->value,
    ];
    if (!empty($this->options['exposed'])) {
      $identifier = $this->options['expose']['identifier'];
      $user_input = $form_state->getUserInput();
      if ($exposed && !isset($user_input[$identifier])) {
        $user_input[$identifier] = $this->value;
        $form_state->setUserInput($user_input);
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public function query() {
    $value = $this->value;
    if ($value) {
      $alias = $this->ensureMyTable();
      // Get current user and take filter value.
      $user = \Drupal::currentUser();

      $membership_loader = \Drupal::service('group.membership_loader');
      $memberships = $membership_loader->loadByUser($user);
      $gids = [];
      foreach ($memberships as $membership) {
        $group = $membership->getGroup();
        $gids[] = $group->id();
        if ($group->bundle() === 'opigno_class') {
          $parent_group_content = GroupRelationship::loadByEntity($group);
          foreach ($parent_group_content as $group_content) {
            $gids[] = $group_content->getGroup()->id();
          }
        }
      }
      $field = $alias . '.id';
      $gids = array_unique($gids);
      if ($gids) {
        // Add condition to select only items with membership.
        $this->query->addWhere($this->options['group'], $field, $gids, 'IN');
      }
      else {
        $this->query->addWhere($this->options['group'], $field, -1, '=');
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  protected function exposedTranslate(&$form, $type) {
    parent::exposedTranslate($form, $type);
    if ($form['#type'] == 'select') {
      $form['#type'] = 'radios';
    }
  }

}
